@@ -8,22 +8,23 @@ import os
 import pytest
 
 from mokkari import api, sqlite_cache
+from mokkari.session import Session
 
 
 @pytest.fixture(scope="session")
-def dummy_username():
+def dummy_username() -> str:
     """Username fixture."""
     return os.getenv("METRON_USERNAME", "username")
 
 
 @pytest.fixture(scope="session")
-def dummy_password():
+def dummy_password() -> str:
     """Password fixture."""
     return os.getenv("METRON_PASSWD", "passwd")
 
 
 @pytest.fixture(scope="session")
-def talker(dummy_username, dummy_password):
+def talker(dummy_username: str, dummy_password: str) -> Session:
     """Mokkari api fixture."""
     return api(
         username=dummy_username,
